@@ -2,9 +2,9 @@ package Term::Choose;
 
 use warnings;
 use strict;
-use 5.008003;
+use 5.10.0;
 
-our $VERSION = '1.744';
+our $VERSION = '1.746';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -108,8 +108,8 @@ sub _defaults {
         #max_cols           => undef,
         #max_height         => undef,
         #max_width          => undef,
-        mouse               => 0,
         #meta_items         => undef,
+        mouse               => 0,
         #no_spacebar        => undef,
         order               => 1,
         pad                 => 2,
@@ -145,7 +145,7 @@ sub __copy_orig_list {
                 s/\e\[[\d;]*m/\x{feff}/g;
             }
             s/\t/ /g;
-            s/[\x{000a}-\x{000d}\x{0085}\x{2028}\x{2029}]+/\ \ /g; # \v 5.10
+            s/\v+/\ \ /g;
             # \p{Cn} might not be up to date and remove assigned codepoints
             # therefore only \p{Noncharacter_Code_Point}
             s/[\p{Cc}\p{Noncharacter_Code_Point}\p{Cs}]//g;
@@ -1222,7 +1222,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.744
+Version 1.746
 
 =cut
 
@@ -1812,7 +1812,7 @@ list context.
 
 =head2 Perl version
 
-Requires Perl version 5.8.3 or greater.
+Requires Perl version 5.10.0 or greater.
 
 =head2 Optional modules
 
@@ -1876,7 +1876,7 @@ L<stackoverflow|http://stackoverflow.com> for the help.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012-2021 Matthäus Kiem.
+Copyright (C) 2012-2022 Matthäus Kiem.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
