@@ -2,9 +2,9 @@ package Term::Choose::LineFold;
 
 use warnings;
 use strict;
-use 5.008003;
+use 5.10.0;
 
-our $VERSION = '1.744';
+our $VERSION = '1.746';
 
 use Exporter qw( import );
 
@@ -99,11 +99,10 @@ sub line_fold {
     if ( ! defined $str || ! length $str ) {
         return $str;
     }
-    my $vertical_space = "[\x{000a}-\x{000d}\x{0085}\x{2028}\x{2029}]"; # \v 5.10
     for ( $opt->{init_tab}, $opt->{subseq_tab} ) {
         if ( defined $_ && length $_ ) {
             s/\t/ /g;
-            s/$vertical_space+/\ \ /g;
+            s/\v+/\ \ /g;
             s/[\p{Cc}\p{Noncharacter_Code_Point}\p{Cs}]//g;
             if ( length > $avail_width / 4 ) {
                 $_ = cut_to_printwidth( $_, int( $avail_width / 2 ) );
@@ -119,15 +118,14 @@ sub line_fold {
         $str =~ s/(\e\[[\d;]*m)/push( @color, $1 ) && "\x{feff}"/ge;
     }
     $str =~ s/\t/ /g;
-    $str =~ s/[^$vertical_space\P{Cc}]//g; # remove control chars but keep vertical spaces
+    $str =~ s/[^\v\P{Cc}]//g; # remove control chars but keep vertical spaces
     $str =~ s/[\p{Noncharacter_Code_Point}\p{Cs}]//g;
-    my $generic_newline = qr/(?>\x{0d}\x{0a}|$vertical_space)/; # \R 5.10
-    if ( $str !~ /$generic_newline/ && print_columns( $opt->{init_tab} . $str ) <= $avail_width && ! @color ) {
+    if ( $str !~ /\R/ && print_columns( $opt->{init_tab} . $str ) <= $avail_width && ! @color ) {
         return $opt->{init_tab} . $str;
     }
     my @paragraphs;
 
-    for my $row ( split /$generic_newline/, $str, -1 ) { # -1 to keep trailing empty fields
+    for my $row ( split /\R/, $str, -1 ) { # -1 to keep trailing empty fields
         my @lines;
         $row =~ s/\s+\z//;
         my @words = split( /(?<=\S)(?=\s)/, $row );
