@@ -2,9 +2,9 @@ package Term::Choose::Opt::Mouse;
 
 use warnings;
 use strict;
-use 5.008003;
+use 5.10.0;
 
-our $VERSION = '1.744';
+our $VERSION = '1.746';
 
 use Term::Choose::Constants qw( :all );
 
